=====
PyDIM
=====

PyDIM is a Python interface to DIM. PyDIM could be used to create DIM clients
and servers, using an API very similar to the one that is used for C.

Check the online documentation at:

    http://lhcbdoc.web.cern.ch/lhcbdoc/pydim/index.html


Installation
============

PyDIM can be installed by following the installation documentation situated at :

    http://lhcbdoc.web.cern.ch/lhcbdoc/pydim/api/index.html

Hacking
=======

Here are some guidelines that may help if you want to modify or just read the
code of pydim.

Directory structure
-------------------

src:
    The part of the extension written in C++
doc:
    Documentation
examples:
    Examples for how to write servers and clients with PyDIM
pydim:
    Additional functions included in the extension, written in Python.
dimbrowser:
    Contains the Python wrapper to the C++ class DimBrowser
setup:
    An old setup script. It should be deprecated.
tests:
    Unit tests. They can be used as a reference.
CI:
    Contains the CI files needed to the Continuous Integration of PyDIM.
examples:
    Examples of how PyDIM fonctionnalities work


The following files are included in the root directory:

INSTALL:
    Instructions for installing and building the RPM

MANIFEST.in:
    A template for the Manifest file used with `distutils`.

setup.cfg:
    Additional configuration for the `distutils` script.

setup.py:
    Installation script

VERSION:
    Version number of the package. It's used in the build process.


Contact
-------

This module was originally developed by Radu Stoica based on code by Niko Neufeld.
Juan Manuel Caicedo improved it significantly and fixed many bugs.

It is currently maintained by Niko Neufeld (niko.neufeld@cern.ch)

Feel free to send your questions and bug reports.
